@@ -51,7 +51,7 @@ static CURLcode test_lib508(const char *URL)
     "this is what we post to the silly web server\n";
 
   CURL *curl;
-  CURLcode result = CURLE_OK;
+  CURLcode res = CURLE_OK;
 
   struct t508_WriteThis pooh;
 
@@ -91,8 +91,8 @@ static CURLcode test_lib508(const char *URL)
   /* include headers in the output */
   test_setopt(curl, CURLOPT_HEADER, 1L);
 
-  /* Perform the request, result will get the return code */
-  result = curl_easy_perform(curl);
+  /* Perform the request, res will get the return code */
+  res = curl_easy_perform(curl);
 
 test_cleanup:
 
@@ -100,5 +100,5 @@ test_cleanup:
   curl_easy_cleanup(curl);
   curl_global_cleanup();
 
-  return result;
+  return res;
 }
